## 1.2.9.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.2.9 (2022-06-26)

deprecated: complete stubs (#8169)

Co-authored-by: hauntsaninja <>

## 1.2.8 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 1.2.7 (2022-04-27)

Drop Python 2 support in third-party stubs (#7703)

## 1.2.6 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 1.2.5 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.2.3 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 1.2.1 (2021-09-06)

Update deprecated.sphinx.deprecated signature (#6005)

The signature was changed in Deprecated 1.2.13.

